/*
** pork.h - pork main include file.
** Copyright (C) 2002 Ryan McCabe <ryan@numb.org>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License, version 2,
** as published by the Free Software Foundation.
*/

#ifndef __PORK_H
#define __PORK_H

#ifdef HAVE___ATTRIBUTE__
	#define __notused __attribute__((unused))
#else
	#define __notused
#endif

#define AUTHOR "Ryan McCabe <ryan@numb.org>"

#include <libfaim/aim.h>
#include <libfaim/faimconfig.h>
#include <pork_util.h>
#include <pork_list.h>
#include <pork_buddy.h>
#include <pork_set.h>
#include <pork_swindow.h>
#include <pork_imwindow.h>
#include <pork_buddy_list.h>

struct aim_rights {
	u_int32_t max_buddies;
	u_int32_t max_watchers;
	u_int32_t max_permit;
	u_int32_t max_deny;
	u_int32_t max_away_len;
	u_int32_t max_profile_len;
};

struct aim_priv {
	u_int32_t ref_count;

	char *username;
	char *passwd;
	char *profile;
	char *away_msg;

	char *proxy;
	char *proxy_user;
	char *proxy_passwd;
	char *server;

	u_int32_t warn_level;
	u_int32_t idle_time;
	u_int32_t flags;
	u_int32_t connected:1;
	u_int32_t marked_idle:1;

	time_t last_update;
	time_t last_input;

	aim_session_t aim_session;
	aim_conn_t *bos_conn;
	struct aim_rights rights;

	struct buddy_pref *buddy_pref;
	struct buddy_list *blist;
};

void pork_exit(int status, char *fmt, ...);
void pork_priv_free(struct aim_priv *priv);
void pork_signoff(void);
struct aim_priv *pork_priv_init(const char *user);

/*
** Yes, this is bad practice.  I don't care.  It makes
** my source files more manageable.
**
** Note how sassy and intractable I am.  What a character.
*/


#include <pork_misc.h>
#include <pork_input.h>
#include <pork_bind.h>
#include <pork_screen.h>
#include <pork_screen_cmd.h>
#include <pork_aim.h>
#include <pork_status.h>
#include <pork_alias.h>
#include <pork_opt.h>
#include <pork_conf.h>
#include <pork_command.h>

extern struct screen screen;

#endif
