/*
** pork_set.c - /SET command implementation.
** Copyright (C) 2002 Ryan McCabe <ryan@numb.org>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License, version 2,
** as published by the Free Software Foundation.
*/

#ifndef __PORK_SET_H
#define __PORK_SET_H

#define OPT_INT				0
#define OPT_CHAR			1
#define OPT_STR				2
#define OPT_BOOL			3

enum {
	OPT_AUTO_RECONNECT = 0,
	OPT_BANNER,
	OPT_BEEP_ON_OUTPUT,
	OPT_CMDCHARS,
	OPT_HISTORY_LEN,
	OPT_LOG,
	OPT_LOGIN_ON_STARTUP,
	OPT_PORK_DIR,
	OPT_PRIVATE_INPUT,
	OPT_REPORT_IDLE,
	OPT_SCROLLBUF_LEN,
	OPT_SCROLL_ON_INPUT,
	OPT_SCROLL_ON_OUTPUT,
	OPT_SEND_REMOVES_AWAY,
	OPT_SHOW_BUDDY_IDLE,
	OPT_SHOW_BUDDY_LIST,
	OPT_TIMESTAMP,
};

enum {
	WOPT_BEEP_ON_OUTPUT = 0,
	WOPT_HISTORY_LEN,
	WOPT_LOG,
	WOPT_LOGFILE,
	WOPT_PRIVATE_INPUT,
	WOPT_SCROLLBUF_LEN,
	WOPT_SCROLL_ON_INPUT,
	WOPT_SCROLL_ON_OUTPUT,
	WOPT_SHOW_BUDDY_LIST,
	WOPT_TIMESTAMP,
	WOPT_NUM_OPTS
};

struct imwindow;

struct global_var {
	char *name;
	u_int32_t type:31;
	u_int32_t dynamic:1;
	int (*set)(u_int32_t, char *);
	void (*updated)(void);
	union {
		u_int32_t i;
		u_int32_t b;
		char c;
		char *s;
	} val;
};

struct window_opts {
	union {
		u_int32_t i;
		u_int32_t b;
		char c;
		char *s;
	} val;
};

struct window_var {
	char *name;
	u_int32_t type;
	int (*set)(struct imwindow *, u_int32_t, char *);
	void (*updated)(struct imwindow *);
};

#define SET_STR(x)	{ .s = (x) }
#define SET_INT(x)	{ .i = (x) }
#define SET_CHAR(x)	{ .c = (x) }
#define SET_BOOL(x)	{ .b = (x) }

void wopt_init(struct window_opts *wopt, const char *target);

u_int32_t wopt_get_int(struct window_opts *wopt, u_int32_t opt);
char *wopt_get_str(struct window_opts *wopt, u_int32_t opt);
char wopt_get_char(struct window_opts *wopt, u_int32_t opt);
u_int32_t wopt_get_bool(struct window_opts *wopt, u_int32_t opt);

u_int32_t opt_get_int(u_int32_t opt);
u_int32_t opt_get_bool(u_int32_t opt);
char opt_get_char(u_int32_t opt);
char *opt_get_str(u_int32_t opt);

void wopt_print_var(struct imwindow *, int var);
void wopt_print(struct imwindow *);

void opt_print_var(int var);
void opt_print(void);

int opt_set(u_int32_t opt, char *args);
int wopt_set(struct imwindow *imwindow, u_int32_t opt, char *args);

int opt_find(const char *name);
int wopt_find(const char *name);

#endif
