/*
** pork_status.c - status bar implementation.
** Copyright (C) 2002 Ryan McCabe <ryan@numb.org>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License, version 2,
** as published by the Free Software Foundation.
*/

#include <config.h>

#include <unistd.h>
#include <ncurses.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include <sys/types.h>

#include <pork.h>

static u_int32_t status_activity(struct screen *screen, char *buf, size_t len);

/*
** this is crap.
*/

int status_init(struct screen *screen) {
	WINDOW *win;

	win = newwin(STATUS_ROWS, screen->cols, screen->rows - STATUS_ROWS, 0);
	if (win == NULL)
		return (-1);

	set_default_win_opts(win);
	screen->status_bar = win;
	return (0);
}

static u_int32_t status_activity(struct screen *screen, char *buf, size_t len) {
	dlist_t *cur = screen->window_list;
	u_int32_t activity = 0;

	buf[0] = '\0';

	do {
		struct imwindow *imwindow = cur->data;
		char num_buf[32];

		if (imwindow->swindow.dirty) {
			if (activity > 0)
				snprintf(num_buf, sizeof(num_buf), ",%u", imwindow->refnum);
			else
				snprintf(num_buf, sizeof(num_buf), "{%u", imwindow->refnum);

			xstrncat(buf, num_buf, len);
			activity++;
		}

		cur = cur->next;
	} while (cur != screen->window_list);

	if (activity > 0)
		xstrncat(buf, "}", len);

	return (activity);
}

void status_draw(struct screen *screen, struct aim_priv *priv) {
	chtype status_line[screen->cols];
	chtype fill_char = ' ' | STATUS_ATTR;
	u_int32_t cur = 0;
	time_t cur_time;
	char timebuf[16];
	char *p;
	struct tm *tm;
	struct imwindow *imwindow = screen->cur_window->data;
	char activity[128];

	cur_time = time(NULL);
	tm = localtime(&cur_time);
	snprintf(timebuf, sizeof(timebuf), "[ %02d:%02d]", tm->tm_hour, tm->tm_min);

	p = timebuf;
	while (*p != '\0' && cur < screen->cols)
		status_line[cur++] = (chtype) *p++ | STATUS_ATTR;

	if (cur < screen->cols)
		status_line[cur++] = fill_char;

	p = priv->username;
	while (*p != '\0' && cur < screen->cols)
		status_line[cur++] = (chtype) *p++ | STATUS_ATTR;

	if (cur < screen->cols)
		status_line[cur++] = fill_char;

	if (cur < screen->cols)
		status_line[cur++] = (chtype) '[' | STATUS_ATTR;

	p = imwindow->name;
	while (*p != '\0' && cur < screen->cols)
		status_line[cur++] = (chtype) *p++ | STATUS_ATTR;

	if (cur < screen->cols)
		status_line[cur++] = (chtype) ']' | STATUS_ATTR;

	status_activity(screen, activity, sizeof(activity));
	if (cur < screen->cols)
		status_line[cur++] = fill_char;

	if (imwindow->typing) {
		char *str;

		if (imwindow->typing == 1)
			str = "(Typing [paused])";
		else
			str = "(Typing)";

		while (*str != '\0' && cur < screen->cols)
			status_line[cur++] = (chtype) *str++ | STATUS_ATTR;

		if (cur < screen->cols)
			status_line[cur++] = fill_char;
	}

	p = activity;
	while (*p != '\0' && cur < screen->cols)
		status_line[cur++] = (chtype) *p++;

	while (cur < screen->cols)
		status_line[cur++] = fill_char;

	mvwputnstr(screen->status_bar, 0, 0, status_line, screen->cols);
	wnoutrefresh(screen->status_bar);
}

#ifdef lasdkasdk

int status_expand_im(char c) {
	switch (c) {
		/* Screen name */
		case 'N':
		case 'n':
			break;

		/* your idle time */
		case 'i':
			break;

		/* your idle time */
		case 'I':
			break;

		case 'T':
		case 't':
			break;

		/* Activity */
		case 'A':
		case 'a':
			break;

		/* Your warning level */
		case 'w':
			break;

		/* buddy's warning level */
		case 'W':
			break;

		/* buddies online */
		case 'n':
			break;

		/* buddies offline */
		case 'N':
			break;
}

#endif
